@@ -5,27 +5,31 @@ ENTITY_CLASS = "EntityClass"
 PROPERTIES   = "properties"
 CONSTRAINTS  = "constraints"
 
-class EntityGeneratorCSV(CSVParser.CSVParser):
 
-    '''
-        ApertureDB Entity Data loader.
+class EntityGeneratorCSV(CSVParser.CSVParser):
+    """**ApertureDB Entity Data loader.**
+
+    .. note::
         Expects a csv file with the following columns:
 
-            EntityClass,PROP_NAME_1, ... PROP_NAME_N,constraint_PROP1
+            ``EntityClass``, ``PROP_NAME_1``, ... ``PROP_NAME_N``, ``constraint_PROP1``
+
+    Example csv file::
 
-        Example csv file:
         EntityClass,name,lastname,age,id,constaint_id
         Person,John,Salchi,69,321423532,321423532
         Person,Johna,Salchi,63,42342522,42342522
         ...
-    '''
+    """
 
     def __init__(self, filename):
 
         super().__init__(filename)
 
-        self.props_keys       = [x for x in self.header[1:] if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
-        self.constraints_keys = [x for x in self.header[1:] if x.startswith(CSVParser.CONTRAINTS_PREFIX) ]
+        self.props_keys       = [x for x in self.header[1:]
+                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+        self.constraints_keys = [x for x in self.header[1:]
+                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
 
     def __getitem__(self, idx):
 
@@ -50,20 +54,22 @@ class EntityGeneratorCSV(CSVParser.CSVParser):
         if self.header[0] != ENTITY_CLASS:
             raise Exception("Error with CSV file field: " + ENTITY_CLASS)
 
-class EntityLoader(ParallelLoader.ParallelLoader):
 
-    '''
-        ApertureDB Entity Loader.
+class EntityLoader(ParallelLoader.ParallelLoader):
+    """**ApertureDB Entity Loader.**
 
         This class is to be used in combination with a "generator".
         The generator must be an iterable object that generated "entity_data"
-        elements:
+        elements.
+
+    Example::
+
             entity_data = {
                 "class":       entity_class,
                 "properties":  properties,
                 "constraints": constraints,
             }
-    '''
+    """
 
     def __init__(self, db, dry_run=False):
 
