@@ -2,10 +2,18 @@ import os
 import sys
 import time
 
+from aperturedb.Connector import Connector
+
 
 class Utils(object):
+    """
+    **A bunch of helper methods to get information from aperturedb.**
 
-    def __init__(self, connector):
+    Args:
+        object (Connector): The underlying Connector.
+    """
+
+    def __init__(self, connector: Connector):
 
         self.connector = connector.create_new_connection()
 
@@ -54,9 +62,30 @@ class Utils(object):
         q = [{
             "CreateIndex": {
                 "index_type":    index_type,
+                "class":         class_name,
+                "property_key":  property_key,
+                "property_type": property_type
+            }
+        }]
+
+        try:
+            res, blobs = self.connector.query(q)
+            if not self.connector.last_query_ok():
+                self.connector.print_last_response()
+                return False
+        except:
+            self.connector.print_last_response()
+            return False
+
+        return True
+
+    def _remove_index(self, index_type, class_name, property_key):
+
+        q = [{
+            "RemoveIndex": {
+                "index_type":   index_type,
                 "class":        class_name,
                 "property_key": property_key,
-                "property_type": property_type
             }
         }]
 
@@ -81,6 +110,14 @@ class Utils(object):
         return self._create_index("connection", class_name,
                                   property_key, property_type)
 
+    def remove_entity_index(self, class_name, property_key):
+
+        return self._remove_index("entity", class_name, property_key)
+
+    def remove_connection_index(self, class_name, property_key):
+
+        return self._remove_index("connection", class_name, property_key)
+
     def count_images(self, constraints={}):
 
         q = [{
@@ -196,7 +233,6 @@ class Utils(object):
             print("Error inserting set", name)
             self.connector.print_last_response()
 
-
     def count_descriptorsets(self):
 
         q = [{
